@@ -27,7 +27,7 @@ data /= data.max()                                           ## normalize data t
 # Define points of interest
 # ============================
 
-poi_list = [[ 50, -30, 5], [-100, 100, 0]]
+poi_list = [[ 50, -30, 5], [-100, 100, 10]]
 
 # ============================
 # Perform rendering
@@ -38,8 +38,8 @@ with cpy.SingleFrameContext((512, 512), fov=90, near=1, far=1000) as rc:
     box = rc.box(20, 20, 20)
     rc.meshes(box, green, poi_list)
     rc.volume(data, spacing=(1, 1, 1), normals=True, fmt_hint=np.uint16)
-    rc.dvr(diffuse_light=1, sample_rate=500)
+    rc.dvr(diffuse_light=1, sample_rate=1000)
     rc.camera.rotate((1.5, 1, 0), 45, 'deg').translate(10, -25, 160).rotate((0, 0, 1), 35, 'deg')
 
-test_tools.assert_rendering('py.demo2', rc.result, max_error=10/255)
+test_tools.assert_rendering('py.demo2', rc.result)
 
